@@ -28,7 +28,7 @@
 #include "capabilities.h"
 #include "tsplog.h"
 #include "obj.h"
-
+#include "tcs_tsp.h"
 
 void
 Trspi_UnloadBlob_NONCE(UINT64 *offset, BYTE *blob, TPM_NONCE *n)
@@ -103,6 +103,10 @@ Trspi_LoadBlob(UINT64 *offset, size_t size, BYTE *to, BYTE *from)
 {
 	if (size == 0)
 		return;
+
+	if ((*offset + size) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (to)
 		memcpy(&to[(*offset)], from, size);
 	(*offset) += size;
@@ -113,6 +117,10 @@ Trspi_UnloadBlob(UINT64 *offset, size_t size, BYTE *from, BYTE *to)
 {
 	if (size <= 0)
 		return;
+
+	if ((*offset + size) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (to)
 		memcpy(to, &from[*offset], size);
 	(*offset) += size;
@@ -121,6 +129,9 @@ Trspi_UnloadBlob(UINT64 *offset, size_t size, BYTE *from, BYTE *to)
 void
 Trspi_LoadBlob_BYTE(UINT64 *offset, BYTE data, BYTE *blob)
 {
+	if ((*offset + sizeof(BYTE)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (blob)
 		blob[*offset] = data;
 	(*offset)++;
@@ -129,6 +140,9 @@ Trspi_LoadBlob_BYTE(UINT64 *offset, BYTE data, BYTE *blob)
 void
 Trspi_UnloadBlob_BYTE(UINT64 *offset, BYTE *dataOut, BYTE *blob)
 {
+	if ((*offset + sizeof(BYTE)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (dataOut)
 		*dataOut = blob[*offset];
 	(*offset)++;
@@ -153,6 +167,9 @@ Trspi_UnloadBlob_BOOL(UINT64 *offset, TSS_BOOL *dataOut, BYTE *blob)
 void
 Trspi_LoadBlob_UINT64(UINT64 *offset, UINT64 in, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT64)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (blob)
 		UINT64ToArray(in, &blob[*offset]);
 	(*offset) += sizeof(UINT64);
@@ -161,6 +178,9 @@ Trspi_LoadBlob_UINT64(UINT64 *offset, UINT64 in, BYTE *blob)
 void
 Trspi_LoadBlob_UINT32(UINT64 *offset, UINT32 in, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT32)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (blob)
 		UINT32ToArray(in, &blob[*offset]);
 	(*offset) += sizeof(UINT32);
@@ -169,6 +189,9 @@ Trspi_LoadBlob_UINT32(UINT64 *offset, UINT32 in, BYTE *blob)
 void
 Trspi_LoadBlob_UINT16(UINT64 *offset, UINT16 in, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT16)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (blob)
 		UINT16ToArray(in, &blob[*offset]);
 	(*offset) += sizeof(UINT16);
@@ -177,6 +200,9 @@ Trspi_LoadBlob_UINT16(UINT64 *offset, UINT16 in, BYTE *blob)
 void
 Trspi_UnloadBlob_UINT64(UINT64 *offset, UINT64 *out, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT64)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (out)
 		*out = Decode_UINT64(&blob[*offset]);
 	(*offset) += sizeof(UINT64);
@@ -185,6 +211,9 @@ Trspi_UnloadBlob_UINT64(UINT64 *offset, UINT64 *out, BYTE *blob)
 void
 Trspi_UnloadBlob_UINT32(UINT64 *offset, UINT32 *out, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT32)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (out)
 		*out = Decode_UINT32(&blob[*offset]);
 	(*offset) += sizeof(UINT32);
@@ -193,6 +222,9 @@ Trspi_UnloadBlob_UINT32(UINT64 *offset, UINT32 *out, BYTE *blob)
 void
 Trspi_UnloadBlob_UINT16(UINT64 *offset, UINT16 *out, BYTE *blob)
 {
+	if ((*offset + sizeof(UINT16)) > TSS_TPM_TXBLOB_SIZE)
+		return;
+
 	if (out)
 		*out = Decode_UINT16(&blob[*offset]);
 	(*offset) += sizeof(UINT16);
@@ -1445,6 +1477,8 @@ Trspi_Error_String(TSS_RESULT r)
 			case TSS_E_INVALID_KEYUSAGE:		return "Invalid usage of key";
 			case TSS_E_VERIFICATION_FAILED:		return "Internal validation of data failed";
 			case TSS_E_HASH_NO_IDENTIFIER:		return "Hash algorithm identifier not set";
+			case TSS_E_NV_AREA_EXIST:		return "NVRAM area already exists";
+			case TSS_E_NV_AREA_NOT_EXIST:		return "NVRAM area does not exist";
 			default:				return "Unknown";
 		}
 	}
@@ -2180,7 +2214,16 @@ Trspi_UnloadBlob_CERTIFY_INFO(UINT64 *offset, BYTE *blob, TPM_CERTIFY_INFO *c)
 	Trspi_UnloadBlob_NONCE(offset, blob, &c->data);
 	Trspi_UnloadBlob_BOOL(offset, (TSS_BOOL *)&c->parentPCRStatus, blob);
 	Trspi_UnloadBlob_UINT32(offset, &c->PCRInfoSize, blob);
-	Trspi_UnloadBlob(offset, c->PCRInfoSize, blob, c->PCRInfo);
+        if (c->PCRInfoSize != 0) {
+                c->PCRInfo = malloc(sizeof(TPM_PCR_INFO));
+                if (c->PCRInfo == NULL) {
+                        LogError("malloc of %lu bytes failed.", sizeof(TPM_PCR_INFO));
+                        return TSPERR(TSS_E_OUTOFMEMORY);
+                }
+        } else {
+                c->PCRInfo = NULL;
+        }
+        Trspi_UnloadBlob_PCR_INFO(offset, blob, (TPM_PCR_INFO *)c->PCRInfo);
 
 	return TSS_SUCCESS;
 }
@@ -2735,3 +2778,63 @@ Trspi_UnloadBlob_CAP_VERSION_INFO(UINT64 *offset, BYTE *blob, TPM_CAP_VERSION_IN
 
 	return TSS_SUCCESS;
 }
+
+TSS_RESULT
+Trspi_UnloadBlob_NV_INDEX(UINT64 *offset, BYTE *blob, TPM_NV_INDEX *v)
+{
+	if (!v) {
+		Trspi_UnloadBlob_UINT32(offset, NULL, blob);
+
+		return TSS_SUCCESS;
+	}
+
+	Trspi_UnloadBlob_UINT32(offset, v, blob);
+
+	return TSS_SUCCESS;
+}
+
+TSS_RESULT
+Trspi_UnloadBlob_NV_ATTRIBUTES(UINT64 *offset, BYTE *blob, TPM_NV_ATTRIBUTES *v)
+{
+	if (!v) {
+		Trspi_UnloadBlob_UINT16(offset, NULL, blob);
+		Trspi_UnloadBlob_UINT32(offset, NULL, blob);
+
+		return TSS_SUCCESS;
+	}
+
+	Trspi_UnloadBlob_UINT16(offset, &v->tag, blob);
+	Trspi_UnloadBlob_UINT32(offset, &v->attributes, blob);
+
+	return TSS_SUCCESS;
+}
+
+TSS_RESULT
+Trspi_UnloadBlob_NV_DATA_PUBLIC(UINT64 *offset, BYTE *blob, TPM_NV_DATA_PUBLIC *v)
+{
+	if (!v) {
+		Trspi_UnloadBlob_UINT16(offset, NULL, blob);
+		Trspi_UnloadBlob_NV_INDEX(offset, blob, NULL);
+		Trspi_UnloadBlob_PCR_INFO_SHORT(offset, blob, NULL);
+		Trspi_UnloadBlob_PCR_INFO_SHORT(offset, blob, NULL);
+		Trspi_UnloadBlob_NV_ATTRIBUTES(offset, blob, NULL);
+		Trspi_UnloadBlob_BYTE(offset, NULL, blob);
+		Trspi_UnloadBlob_BYTE(offset, NULL, blob);
+		Trspi_UnloadBlob_BYTE(offset, NULL, blob);
+		Trspi_UnloadBlob_UINT32(offset, NULL, blob);
+
+		return TSS_SUCCESS;
+	}
+
+	Trspi_UnloadBlob_UINT16(offset, &v->tag, blob);
+	Trspi_UnloadBlob_NV_INDEX(offset, blob, &v->nvIndex);
+	Trspi_UnloadBlob_PCR_INFO_SHORT(offset, blob, &v->pcrInfoRead);
+	Trspi_UnloadBlob_PCR_INFO_SHORT(offset, blob, &v->pcrInfoWrite);
+	Trspi_UnloadBlob_NV_ATTRIBUTES(offset, blob, &v->permission);
+	Trspi_UnloadBlob_BYTE(offset, &v->bReadSTClear, blob);
+	Trspi_UnloadBlob_BYTE(offset, &v->bWriteSTClear, blob);
+	Trspi_UnloadBlob_BYTE(offset, &v->bWriteDefine, blob);
+	Trspi_UnloadBlob_UINT32(offset, &v->dataSize, blob);
+
+	return TSS_SUCCESS;
+}
