@@ -44,6 +44,7 @@ Tspi_Context_LoadKeyByUUID(TSS_HCONTEXT tspContext,		/* in */
 	TCS_LOADKEY_INFO info;
 	UINT32		ulPubKeyLength;
 	BYTE		*rgbPubKey;
+	TPM_COMMAND_CODE ordinal;
 
 	if (phKey == NULL)
 		return TSPERR(TSS_E_BAD_PARAMETER);
@@ -51,6 +52,9 @@ Tspi_Context_LoadKeyByUUID(TSS_HCONTEXT tspContext,		/* in */
 	if ((!obj_is_context(tspContext)))
 		return TSPERR(TSS_E_INVALID_HANDLE);
 
+	if ((result = obj_context_get_loadkey_ordinal(tspContext, &ordinal)))
+		return result;
+
 	/* This key is in the System Persistant storage */
 	if (persistentStorageType == TSS_PS_TYPE_SYSTEM) {
 #if 1
@@ -78,7 +82,7 @@ Tspi_Context_LoadKeyByUUID(TSS_HCONTEXT tspContext,		/* in */
 						  &hPolicy, NULL))
 				return result;
 
-			if (secret_PerformAuth_OIAP(keyHandle, TPM_ORD_LoadKey, hPolicy, FALSE,
+			if (secret_PerformAuth_OIAP(keyHandle, ordinal, hPolicy, FALSE,
 						    &info.paramDigest, &info.authData))
 				return result;
 
